<template>
    <div class="sewers-search" v-if="gdVisible">
        <div class="panel-title">{{ title }}</div>
        <el-tabs v-model="activeName" @tab-click="handleClick">
            <el-tab-pane label="查询" name="first">
                <div class="search-panel ">
                    <el-form ref="form" :model="form" label-width="90px" class="search-form">
                        <el-form-item label="设施类型：" size="mini" class="search-panel-item">
                            <el-select style="width: 100%" v-model="form.pipelineType"
                                       :popper-class="'select-down'">
                                <el-option
                                        v-for="item in items"
                                        :key="item.code"
                                        :label="item.name"
                                        :value="item.name">
                                </el-option>
                            </el-select>
                        </el-form-item>
                        <el-form-item :label="form.pipelineType+'：'" size="mini">
                            <el-select style="width: 100%" v-model="form.dataType" value-key="code"
                                       :popper-class="'select-down'" @change="handleDataType">
                                <el-option
                                        v-for="item in subItems"
                                        :key="item.code"
                                        :label="item.name"
                                        :value="item">
                                </el-option>
                            </el-select>
                        </el-form-item>
                        <div class="rightButtonSearch">
                            <el-input v-model="form.keyword" size="mini" placeholder="在此输入关键字搜索"></el-input>
                            <el-button class="el-icon-search" @click="handleSearch"></el-button>
                        </div>
                    </el-form>
                </div>
                <el-scrollbar style="height:413px;">
                    <div class="environmental-risk-list" v-for="(item,index) in list" :key="index"
                         :class="activeNum===index?'hover':''">
                        <img class="state" :src="getImgSrc()" style="background: none"/>
                        <div>
                            <h3 @click="handleLocation(item,index)">{{ item.properties.name || item.properties.code
                                }}</h3>
                            <p>所属企业：<span>{{ item.properties.orgname }}</span>
                            <p>设施类型：<span>{{ item.properties.type }}</span>
                                <el-button v-if="fuShuSheShiShow" class="rt btn00fff6" size="mini"
                                           style="margin-right: 0.04rem;"
                                           @click="btnAffiliatedFacilities(item,index)">
                                    附属设施
                                </el-button>
                            </p>
                        </div>
                    </div>
                </el-scrollbar>
                <el-card class="footer-page" v-if="total > 10">
                    <el-pagination
                            small
                            @current-change="handlePage"
                            :page-size=pageSize
                            layout="prev, pager, next"
                            :total=total
                            class="warnPagination"
                    >
                    </el-pagination>
                </el-card>
            </el-tab-pane>
            <el-tab-pane label="分析" name="second">
                <SewersAnalysis></SewersAnalysis>
            </el-tab-pane>
            <el-tab-pane label="历史" name="third">
                <SewersHistory></SewersHistory>
            </el-tab-pane>
        </el-tabs>
        <!-- 附属设施面板 -->
        <affiliated-facilities :facilitiesParameter="facilitiesParameter"
                               v-if="fuShuSheShiShow"></affiliated-facilities>
    </div>
</template>

<script>
// 引入组件内容 =》 附属设施
import AffiliatedFacilities from '@components/BaseNav/pipeline/AffiliatedFacilities'
// 管线分析功能
import SewersAnalysis from '@components/panel/topicSearch/SewersSelect/SewersAnalysis'
// 管线查询历史功能
import SewersHistory from '@components/panel/topicSearch/SewersSelect/SewersHistory'
// form类型可选择数据 图层控制
import { LayerPipeLines } from '@src/conf/layers/LayerPipeLines'
import { LayerFsss } from '@src/conf/layers/LayerFsss'
import { LayerHbss } from '@src/conf/layers/LayerHbss'
import { LayerPk } from '@src/conf/layers/LayerPk'
import { LayerArea } from '@src/conf/layers/LayerArea'
// 方法
import WfsHelper from '@components/helpers/WfsHelper'
import AjaxUtils from '@utils/AjaxUtils'
import { fitBounds, highlight, locate } from '../../helpers/LocateHelper'

export default {
  name: 'SewersSearch',
  props: ['title'],
  components: {
    SewersAnalysis,
    SewersHistory,
    AffiliatedFacilities
  },
  data () {
    return {
      // 判断显示/隐藏
      gdVisible: true,
      // tab切换 绑定当前值
      activeName: 'first',
      // 搜索数据 用于展示数据存储
      list: [],
      // 图层控制
      items: [LayerPipeLines, LayerFsss, LayerHbss, LayerPk, LayerArea],
      // 分页
      pageSize: 10,
      total: 0,
      // form表单绑定数据
      form: {
        pipelineType: '管线',
        dataType: '',
        keyword: ''
      },
      facilitiesParameter: null,
      fuShuSheShiShow: true,
      activeNum: -1,
      wfsHelper: null
    }
  },
  computed: {
    subItems () {
      const val = this.form.pipelineType
      for (let i = 0; i < this.items.length; i++) {
        const item = this.items[i]
        if (val === item.name) {
          return item.layers.filter(function (value, index, array) {
            return value.name !== '流向'
          })
        }
      }
      return []
    }
  },
  mounted () {
    this.wfsHelper = new WfsHelper()
  },
  methods: {
    // tab切换
    handleClick (tab, event) {
      console.log(tab, event)
      // if (tab.label === '分析') {
      //   // 关闭弹窗
      //   window.mapManager.clickDialogSwitch = false
      // } else {
      //   // 打开弹窗
      //   window.mapManager.clickDialogSwitch = true
      // }
    },
    // 根据返回数据 确认展示图片
    getImgSrc () {
      const icon = this.form.dataType.icon
      return icon ? 'assets/images/map/' + icon : ''
    },
    // 页面切换 分页功能
    handlePage (page) {
      this.wfsHelper.setPage(page)
      this.handleSearch()
    },
    // 二级form表单切换选择清空已选择数据
    handleDataType () {
      this.list = []
    },
    // 搜索功能
    async handleSearch () {
      // console.log(this.form.dataType.sname, this.form.keyword)
      this.list = []
      this.wfsHelper.clearFilter()
      // todo 现在管网还没区分开类型，后面改
      this.wfsHelper.setTypeName(['sewer:view_pipeline'])
      if (this.form.keyword) {
        this.wfsHelper.addLike('name', this.form.keyword)
      }
      this.wfsHelper.addEquals('type', '\'' + this.form.dataType.sname + '\'')
      // const filter = this.form.dataType.filter
      // if (filter) {
      //   this.wfsHelper.setFilter(filter)
      // }
      // const _this = this
      const res = await AjaxUtils.GetDataAsynByUrl(this.wfsHelper.getUrl(), {})
      if (res instanceof Object && Object.prototype.hasOwnProperty.call(res, 'features')) {
        this.total = res.totalFeatures
        this.list = res.features
      }
      this.wfsHelper = new WfsHelper()
    },
    // 点击搜索到的数据 实现功能 = 定位 高亮 弹框
    handleLocation (val, index) {
      // console.log(val)
      this.activeNum = index
      // layer && layer.openPopup()
      const config = this.form.dataType
      locate(val, config)
    },
    // 附属设施功能组件
    btnAffiliatedFacilities (val, index) {
      this.activeNum = index
      this.facilitiesParameter = val
      // 判断选择是否是管线，如果是则显示《附属设施》弹框
      if (this.form.pipelineType === '管线') {
        this.fuShuSheShiShow = true
      } else {
        this.fuShuSheShiShow = false
      }
      fitBounds(val, this.form.dataType.code)
      highlight(val)
    }
  }
}
</script>

<style lang="less" scoped>

</style>
